@@ -12,6 +12,7 @@ import time
 import requests
 import sqlite3
 from datetime import date
+from hiveengine.api import Api
 from hiveengine.wallet import Wallet
 
 ### Global configuration
@@ -33,6 +34,8 @@ beem.instance.set_shared_blockchain_instance(HIVE)
 ACCOUNT = Account(ACCOUNT_NAME)
 TOKEN_NAME = config['HiveEngine']['TOKEN_NAME']
 
+api = Api(url = "https://engine.rishipanthee.com")
+
 BOT_COMMAND_STR = config['Global']['BOT_COMMAND_STR']
 
 SQLITE_DATABASE_FILE = 'alivebot.db'
@@ -189,8 +192,14 @@ def get_invoker_level(invoker_name):
     # check how much TOKEN the invoker has
     wallet_token_info = Wallet(invoker_name).get_token(TOKEN_NAME)
 
-    invoker_delegationsIn = float(wallet_token_info['delegationsIn'] or 0)
-    invoker_stake = float(wallet_token_info['stake'] or 0)
+    try:
+        invoker_delegationsIn = float(wallet_token_info['delegationsIn'])
+    except:
+        invoker_delegationsIn = float(0)
+    try:
+        invoker_stake = float(wallet_token_info['stake'])
+    except:
+        invoker_stake = float(0)
 
     # does invoker meet level 4 requirements?
     min_staked = float(config['AccessLevel4']['MIN_TOKEN_STAKED'])
